/*-------------------------------------------------------------------
Name......... fpga.h
Author....... Marc Adams
Date......... 15/09/03
Description.. Header file for the Heber reference FPGA
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/

/****   Defines */

#define BOOT16 0    /* Define boot block size */

#define FPGA_SIG 0x01 /* Value Of ID Byte */

/********************************************************************
*** FPGA Register Definitions
********************************************************************/
#define FPGA_REG_BASE   (FPGA_BASE+0x000)           /* Register Base Address */

#define XCRA        (BYTE*)(FPGA_REG_BASE + 0x00)   /* FPGA Control Reg */
#define XMPX        (BYTE*)(FPGA_REG_BASE + 0x01)   /* MPX Control Reg */
#define FPGA_ID     (BYTE*)(FPGA_REG_BASE + 0x01)   /* FPGA I/D */
#define XSFXVOL     (BYTE*)(FPGA_REG_BASE + 0x02)   /* SFX VOL */
#define FPGA_ISS    (BYTE*)(FPGA_REG_BASE + 0x02)   /* FPGA ISSUE */
#define XUCTRL      (BYTE*)(FPGA_REG_BASE + 0x03)   /* UART CTRL/ROUTE */
#define XMISC_IP    (BYTE*)(FPGA_REG_BASE + 0x04)   /* Read Misc Inputs Like Meter Sense Etc */
#define SFXR1       (BYTE*)(FPGA_REG_BASE + 0x04)   /* SFX CH 1 */
#define SFXR2       (BYTE*)(FPGA_REG_BASE + 0x06)   /* SFX CH 2 */
#define XDUARTROUTE (BYTE*)(FPGA_REG_BASE + 0x08)   /* DUART Routing Register */
#define CRCCHECK    (BYTE*)(FPGA_REG_BASE + 0x09)   /* CRC Write */

/*******************************************************************
*** FPGA Register Bit Definitions
*******************************************************************/
/* XCRA Control register A */
#define SFX_ENABLE		0x80 /* enable sound */
#define IRQ_ENABLE		0x40 /* enable FGPA interupts */
#define MPX_ENABLE		0x20 /* multiplex drivers enable */
#define SYNC_ENABLE		0x10 /* dual video: synchronize second video board to first video board */

/* XMISC_IP Bits */
#define METER_SENSE     0x10
#define PUSH_BUTTON     0x02

/*******************************************************************
*** MPX RAM Base Address
*******************************************************************/
#define MPXBASE     (LONG*)(FPGA_BASE+0x800) /* MPX Register Base */

/*******************************************************************
*** I/O Definitions
*******************************************************************/
    /* IO Base Address */
#define FPGA_IO_BASE    (FPGA_BASE+0x1800)

/* IO Chip Selects Base Address */
#define FPGA_IO_CS0 (FPGA_IO_BASE)
#define FPGA_IO_CS1 (FPGA_IO_BASE+0x100)
#define FPGA_IO_CS2 (FPGA_IO_BASE+0x200)

#define OUTPUTS     (BYTE*)(FPGA_IO_CS0)    /* Outputs */
#define INPUTS      (BYTE*)(FPGA_IO_CS0)    /* Inputs */

#define AUX_BASE    (FPGA_IO_CS1)           /* AUX (TTL) Outputs */
#define AUX0        (BYTE*)(AUX_BASE+0x00)  /* AUX 0 */
#define AUX1        (BYTE*)(AUX_BASE+0x01)  /* AUX 1 */
#define AUX2        (BYTE*)(AUX_BASE+0x02)  /* AUX 2 */
#define AUX3        (BYTE*)(AUX_BASE+0x03)  /* AUX 3 */
#define AUX4        (BYTE*)(AUX_BASE+0x04)  /* AUX 4 */
#define AUX5        (BYTE*)(AUX_BASE+0x05)  /* AUX 5 */
#define AUX6        (BYTE*)(AUX_BASE+0x06)  /* AUX 6 */
#define AUX7        (BYTE*)(AUX_BASE+0x07)  /* AUX 7 */

/*******************************************************************
*** UART Definitions
*******************************************************************/
/* UART BASE ADDRESS */
#define FPGA_UART_BASE (void*)(FPGA_BASE + 0x1000)

/* FPGA UART BASE ADDRESS */
#define FPGA_UART0_BASE (LONG)(FPGA_UART_BASE  + 0x0000) /* Base Reg */
#define FPGA_UART1_BASE (LONG)(FPGA_UART_BASE  + 0x0004) /* Base Reg */

/* DUART BASE ADDRESS */
#define DUART0BASE  (void*)(FPGA_UART_BASE  + 0x010) /* Base Reg */

/*******************************************************************
*** Calypso 32 Base Address Definitions
*******************************************************************/
/**/
#define CALYPSO32PLUS_BASE	(LONG)(0x30000000)				/* CS3 */
#define CALYPSO32DUAL0_BASE	(LONG)(0x30000000)				/* CS3 */
#define CALYPSO32DUAL1_BASE	(LONG)(0x30000000+0x4000000)	/* CS3 + 64M */

/*******************************************************************
*** Pluto 6 Chip Select Setup
*******************************************************************/

#define CSAR0   0x0000          /* CS0 8/16 Bit */

#if BOOT16
	#define CSCR0   0x11D3
	#define CSAMR0  0x00FF0000
#else
    #define CSCR0   0x1153
	#define CSAMR0  0x000F0000
#endif

#define CSAR1   0x1000          /* CS1 */
#define CSAMR1  0x0FFF0000
#define CSCR1   0x00D3

#define CSAR2   0x2000          /* CS2 */
#define CSAMR2  0x0FFF0000
#define CSCR2   0x005F

#define CSAR3   0x3000          /* CS3 */
#define CSAMR3  0x0FFF0000
#define CSCR3   0x0013

/*******************************************************************
*** Pluto 6 Coldfire Internal RAM Address
*******************************************************************/
#define RAMBAR  0x50000001

/****   Type Definitions */
/****   Prototypes */

    #include    "fpga.p"

/******************************************************************/
